package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.28.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.28.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````(`/@`!````$"9```````!``````````#"S````
M`````````$``.``,`$``&P`:``8````$````0`````````!``$```````$``
M0```````H`(```````"@`@````````@``````````P````0```#@`@``````
M`.`"0```````X`)````````<`````````!P``````````0`````````!````
M!`````````````````!``````````$```````!`:````````$!H`````````
M$`````````$````%`````"``````````($`````````@0```````K3L`````
M``"M.P`````````0`````````0````0`````8`````````!@0````````&!`
M````````1@````````!&`````````!`````````!````!@```&BM````````
M:+U```````!HO4```````*@$`````````!4`````````$`````````(````&
M````>*T```````!XO4```````'B]0```````,`(````````P`@````````@`
M````````!`````0```#\`@```````/P"0```````_`)```````!$````````
M`$0`````````!`````````!0Y71D!````$B?````````2)]```````!(GT``
M`````.P`````````[``````````$`````````%'E=&0&````````````````
M`````````````````````````````````````````!``````````4N5T9`0`
M``!HK0```````&B]0```````:+U```````"8`@```````)@"`````````0``
M``````"`%01E`"@`````````````````````````````````````````````
M```````````(`````````"]L:6(V-"]L9"UL:6YU>"UX.#8M-C0N<V\N,@`$
M````$`````$```!'3E4```````,````"``````````0````4`````P```$=.
M50!@.`ADI>O7?'B=Z%\X'&-E)]+\K1$```!)````!`````@````@$!``!4`$
MA"@"``"`A@"`@@D```D@!`B(H!!%N@`""`````!)````3````$\```!0````
M5@```%<```!8````6@```%L`````````70```%X```!?````8```````````
M````;L7?'\[>1RUK?YI\+L6;MM1DU'PA_^0.V7%8'.)'Q@&R`8MOK$OCP,+E
M/RRZXY)\^Z%L8&L)0]9GK\QF0D75[(D'<-,-%.*>,F+;[=O-XYX-.I<+?ZF<
MF^&G`@JCX/M)``````````````````````````````````````X"```2````
M``````````````````````X!```2`````````````````````````)4````2
M``````````````````````````,!```1`````````````````````````*T"
M```2`````````````````````````.,!```2````````````````````````
M`$4#```1`````````````````````````)4!```2````````````````````
M`````&@"```2`````````````````````````)@"```2````````````````
M`````````"0!```2`````````````````````````!,````@````````````
M`````````````"P"```2`````````````````````````$T#```2````````
M`````````````````/$!```2`````````````````````````#$"```2````
M`````````````````````*P!```2`````````````````````````#$#```2
M`````````````````````````%4!```2`````````````````````````+8`
M```2`````````````````````````$4!```2````````````````````````
M`%,"```2`````````````````````````)("```2````````````````````
M`````#<!```2`````````````````````````.\"```2````````````````
M`````````&\"```2`````````````````````````$,#```1````````````
M`````````````/,#```2`````````````````````````"(````@````````
M`````````````````+,!```2`````````````````````````!,!```2````
M`````````````````````(0"```2`````````````````````````#X````@
M`````````````````````````,8"```2`````````````````````````%@`
M```2`````````````````````````(4!```2````````````````````````
M`'4````2`````````````````````````/(````2````````````````````
M`````(8````2`````````````````````````/8!```2````````````````
M`````````(L"```2`````````````````````````-8````2````````````
M`````````````.8"```2`````````````````````````'<!```2````````
M`````````````````!L#```2`````````````````````````/P"```2````
M`````````````````````+L"```2`````````````````````````&D!```2
M`````````````````````````/T!```2`````````````````````````'8"
M```2`````````````````````````!@!```2````````````````````````
M`$("```2`````````````````````````"H#```2````````````````````
M`````'T"```2`````````````````````````-\"```2````````````````
M`````````*$````2`````````````````````````,X"```2````````````
M`````````````*`!```2`````````````````````````.D!```2````````
M`````````````````#D"```2``````````````````````````T#```2````
M`````````````````````-@"```1`````````````````````````.4````1
M`````````````````````````",#```2`````````````````````````$0#
M```A`````````````````````````&`"```2````````````````````````
M`%X!```2`````````````````````````&8````2````````````````````
M`````*8"```2``````````````````````````,#```2````````````````
M`````````%H"```2`````````````````````````,0````2````````````
M`````````````/P#```2``T`L%I```````!>`````````$T$```2``T`P$M`
M```````@"P```````#X#```2``T`X"-````````A`@```````&T#```2``T`
M($5````````%`````````)L#```2``T`X%9```````##`P```````',$```2
M``T`,$5````````"`@```````#P$```0`!@`$,)``````````````````'X#
M```2``T`0$=````````I`````````+$#```2``T`,$I```````!T````````
M``@$```1``\``&!````````$`````````"0$```2``T`T$-````````S````
M`````$@$```0`!@`:-)``````````````````&$$```2``T`X$I```````#>
M`````````!<$```0`!<`\,%``````````````````-4#```2``T`<$=`````
M``#-`````````%H$```0`!<`$,)``````````````````(`$```1`!<`",)`
M```````(`````````(L#```2``T`@%M````````%`````````!T$```2``T`
M$"9````````O`````````"P$```2``T`$%M```````!E`````````!D$```@
M`!<`\,%``````````````````.$#```2``T`L$I````````G`````````+\#
M```2``T`8$1```````"Z`````````(H$```2``T`0$A```````#G`0``````
M``!L:6)P97)L+G-O+C4N,C@N,`!?7V=M;VY?<W1A<G1?7P!?251-7V1E<F5G
M:7-T97)434-L;VYE5&%B;&4`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!0
M97)L7W-Y<U]T97)M`%!E<FQ?<WES7VEN:70S`%!E<FQ?871F;W)K7VQO8VL`
M<&5R;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O;G1E
M>'0`4&5R;%]A=E]S:&EF=`!097)L7W-V7S)P=E]F;&%G<P!097)L7W-V7W-E
M='!V;@!03%]D;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!03%]T:')?:V5Y
M`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R
M;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]N97=8
M4P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A9&5R
M`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`;&EB
M9&PN<V\N,@!L:6)M+G-O+C8`;&EB<'1H<F5A9"YS;RXP`&-L;W-E`&QS965K
M-C0`<F5A9`!O<&5N-C0`7U]E<G)N;U]L;V-A=&EO;@!P=&AR96%D7V=E='-P
M96-I9FEC`&QI8F,N<V\N-@!E>&ET`'-T<FYC;7``8VQO<V5D:7(`7U]S=&%C
M:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A;&QO8P!M96UC:'(`9V5T<&ED
M`'-T<F1U<`!S=')T;VL`<W1R;&5N`'-T<G-T<@!R;61I<@!?7V9P<FEN=&9?
M8VAK`&UE;6-P>0!?7W-T<FYC<'E?8VAK`%]?;'AS=&%T-C0`;W!E;F1I<@!?
M7WAS=&%T-C0`<W1D97)R`&=E='5I9`!R96%D;&EN:P!?7VUE;6-P>5]C:&L`
M<W1R8VAR`')E861D:7(V-`!?7W-P<FEN=&9?8VAK`&UE;6UO=F4`86-C97-S
M`'-T<F-M<`!?7VQI8F-?<W1A<G1?;6%I;@!?7V5N=FER;VX`7U]R96=I<W1E
M<E]A=&9O<FL`;&EB8W)Y<'0N<V\N,0!P87)?8W5R<F5N=%]E>&5C`'!A<E]B
M87-E;F%M90!?7VQI8F-?8W-U7V9I;FD`6%-?26YT97)N86QS7U!!4E]"3T]4
M`'!A<E]E;G9?8VQE86X`<&%R7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]D:7)N
M86UE`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%])
M3U]S=&1I;E]U<V5D`%]?9&%T85]S=&%R=`!X<U]I;FET`%]?;&EB8U]C<W5?
M:6YI=`!?7V)S<U]S=&%R=`!?96YD`'!A<E]M:W1M<&1I<@!?961A=&$`<&%R
M7W-E='5P7VQI8G!A=&@`<&%R7V9I;F1P<F]G`&UY7W!A<E]P;`!P87)?:6YI
M=%]E;G8`1TQ)0D-?,BXQ-`!'3$E"0U\R+C0`1TQ)0D-?,BXS+C(`1TQ)0D-?
M,BXR+C4`1TQ)0D-?,BXS+C0`+W5S<B]L:6(V-"]P97)L-2\U+C(X+C`O>#@V
M7S8T+7!L9"UL:6YU>"UT:')E860M;75L=&DO0T]210`````"``````````,`
M`@`$````!``#```````$``4``@`$``0`!``````````$``0````#``0`!``$
M```````$``0````$```````````````"``0````$````!``$``0````"``0`
M```&``0`!``$````!`````(`!``#``0````$``0`!```````!P`$``0````!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0````$`!0`B`@``$````&````"4D98&```'`)<$```0````%&EI#0``!@"B
M!```$````'(9:0D```4`K`0``!````!U&FD)```$`+@$```0````=!EI"0``
M`P#$!`````````$``0#3`0``$`````````!U&FD)```"`+@$````````J+]`
M```````&````!```````````````L+]````````&````!P``````````````
MN+]````````&````"P``````````````P+]````````&````#```````````
M````R+]````````&````$@``````````````T+]````````&````'0``````
M````````V+]````````&````(0``````````````X+]````````&````)```
M````````````Z+]````````&````)0``````````````\+]````````&````
M/@``````````````^+]````````&````/P``````````````&,!````````'
M`````0``````````````(,!````````'`````@``````````````*,!`````
M```'`````P``````````````,,!````````'````!0``````````````.,!`
M```````'````!@``````````````0,!````````'````"```````````````
M2,!````````'````"0``````````````4,!````````'````"@``````````
M````6,!````````'````#0``````````````8,!````````'````#@``````
M````````:,!````````'````#P``````````````<,!````````'````$```
M````````````>,!````````'````$0``````````````@,!````````'````
M$P``````````````B,!````````'````%```````````````D,!````````'
M````%0``````````````F,!````````'````%@``````````````H,!`````
M```'````%P``````````````J,!````````'````&```````````````L,!`
M```````'````&0``````````````N,!````````'````&@``````````````
MP,!````````'````'```````````````R,!````````'````'@``````````
M````T,!````````'````'P``````````````V,!````````'````(```````
M````````X,!````````'````(@``````````````Z,!````````'````(P``
M````````````\,!````````'````)@``````````````^,!````````'````
M)P```````````````,%````````'````*```````````````",%````````'
M````*0``````````````$,%````````'````*@``````````````&,%`````
M```'````*P``````````````(,%````````'````+```````````````*,%`
M```````'````+0``````````````,,%````````'````+@``````````````
M.,%````````'````+P``````````````0,%````````'````,```````````
M````2,%````````'````,0``````````````4,%````````'````,@``````
M````````6,%````````'````,P``````````````8,%````````'````-```
M````````````:,%````````'````-0``````````````<,%````````'````
M-@``````````````>,%````````'````-P``````````````@,%````````'
M````.```````````````B,%````````'````.0``````````````D,%`````
M```'````.@``````````````F,%````````'````.P``````````````H,%`
M```````'````/```````````````J,%````````'````/0``````````````
ML,%````````'````0```````````````N,%````````'````0@``````````
M````P,%````````'````0P``````````````R,%````````'````1```````
M````````T,%````````'````10``````````````V,%````````'````1@``
M````````````X,%````````'````1P``````````````Z,%````````'````
M2```````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#S#Q[Z2(/L"$B+!;&?``!(A<!T`O_02(/$",,``````/\UXI\``/\EY)\`
M``\?0`#_)>*?``!H`````.G@_____R7:GP``:`$```#IT/____\ETI\``&@"
M````Z<#_____)<J?``!H`P```.FP_____R7"GP``:`0```#IH/____\ENI\`
M`&@%````Z9#_____);*?``!H!@```.F`_____R6JGP``:`<```#I</____\E
MHI\``&@(````Z6#_____)9J?``!H"0```.E0_____R62GP``:`H```#I0/__
M__\EBI\``&@+````Z3#_____)8*?``!H#````.D@_____R5ZGP``:`T```#I
M$/____\E<I\``&@.````Z0#_____)6J?``!H#P```.GP_O___R5BGP``:!``
M``#IX/[___\E6I\``&@1````Z=#^____)5*?``!H$@```.G`_O___R5*GP``
M:!,```#IL/[___\E0I\``&@4````Z:#^____)3J?``!H%0```.F0_O___R4R
MGP``:!8```#I@/[___\E*I\``&@7````Z7#^____)2*?``!H&````.E@_O__
M_R4:GP``:!D```#I4/[___\E$I\``&@:````Z4#^____)0J?``!H&P```.DP
M_O___R4"GP``:!P```#I(/[___\E^IX``&@=````Z1#^____)?*>``!H'@``
M`.D`_O___R7JG@``:!\```#I\/W___\EXIX``&@@````Z>#]____)=J>``!H
M(0```.G0_?___R72G@``:"(```#IP/W___\ERIX``&@C````Z;#]____)<*>
M``!H)````.F@_?___R6ZG@``:"4```#ID/W___\ELIX``&@F````Z8#]____
M):J>``!H)P```.EP_?___R6BG@``:"@```#I8/W___\EFIX``&@I````Z5#]
M____)9*>``!H*@```.E`_?___R6*G@``:"L```#I,/W___\E@IX``&@L````
MZ2#]____)7J>``!H+0```.D0_?___R5RG@``:"X```#I`/W___\E:IX``&@O
M````Z?#\____)6*>``!H,````.G@_/___R5:G@``:#$```#IT/S___\E4IX`
M`&@R````Z<#\____)4J>``!H,P```.FP_/___R5"G@``:#0```#IH/S___\E
M.IX``&@U````Z9#\____)3*>``!H-@```.F`_/___R4JG@``:#<```#I</S_
M__\E(IX``&@X````Z6#\____)1J>``!H.0```.E0_/___R42G@``:#H```#I
M0/S__U532(/L.(E\)!Q(C7PD'$B)="002(UT)!!(B50D"$B-5"0(9$B+!"4H
M````2(E$)"@QP.AX____2(LUF9L``$B+/<*;``!(B?+H8C<``$B+!<.;``"`
M.``/A#0!``!(BQUCFP``BSOHY/O__XL[2(T==#T``("(.@0```+HS_O__X"(
M.@0```&+1"0<C7@%2&/_2,'G`^BE_O__3(M,)!#'!<:M```$````2(D%MZT`
M`$F+$4B)6`A(C1TM/0``2(E8&$B)$$C'P@C"0`!(BQ)(B5`0BU0D'(/Z`7XK
MC4K^O@$```!(@\$"#Q^``````$V+!/&-?@1(@\8!2&/_3(E$^/A(.?%UZ(U*
M!$4QP(/"`TB+/6BM``!(8\E(C34.'P``2,=$R/@`````2(G!Z&W[__^)PX7`
M#X2(````2(L]/*T``$B-;"0DZ%+]__\QP$B)[DB-/6H[``#HX1<``$B%P'1T
M2(L]%:T``.CP^O__Z'O\__^)V$B+7"0H9$@S'"4H````#X6'````2(/$.%M=
MP^@9_/__2(D%XJP``$B%P'1T2(G'Z&7\__](BQT6F@``BSOHE_K__\:`T0D`
M``#IH/[__TB+/;2L``#H3_O__XG#Z67___](BSV9K```2(7_=`KHYS0``.EV
M____2(T]A#H``$B)[NA#%P``2(G'2(D%<:P``$B%P`^$5/___^O2Z,G\__^_
M`0```.BO^O__9BX/'X0```````\?1```\P\>^C'M28G17DB)XDB#Y/!05$G'
MP(!;0`!(Q\$06T``2,?'X"-``/\5BID``/20\P\>^L-F+@\?A```````D$B-
M/;F;``!(C06RFP``2#GX=!5(BP5FF0``2(7`=`G_X`\?@`````###Q^`````
M`$B-/8F;``!(C36"FP``2"G^2,'^`TB)\$C!Z#](`<9(T?YT%$B+!2V9``!(
MA<!T"/_@9@\?1```PP\?@`````"`/5F;````=1=52(GEZ'[____&!4>;```!
M7<,/'T0``,-F9BX/'X0```````\?0`#KCF8N#Q^$```````/'T``05=,C4<X
M3(U7>$%6055!5%532('LF`(``&1(BP0E*````$B)A"2(`@``,<!(B>))B=%F
M#Q]$``!!BP!)BS!)@\`(28/!$`_(B<!(B?%)B4'P2(GP2,'I($C!Z"A(P>XX
M)0#_``!("?!(B<Y(P>$(2,'F&('A``#_`(GV2`GP2`G(28E!^$TYPG6N2(VR
M``(```\?@`````!(BT)H2#-"0$B#P@A(,T((2#-"^$B-#`!(P>@?2`G(@^#_
M2(E">$@Y\G753(L72(M?$$B+=R!(BV\83(G03(G23(M/"$C!ZAM(P>`%2`G0
M`P0DC90PF7F"6DB)V$B+="0(2#'H3"'(2(VT-9EY@EI(,>A$C2P"3(G*3(G(
M2,'H`DC!XAY-B>A("<)(B=A)P>@;B=%(,<A,(=!(,=A(`?!,B>Y(P>8%3`G&
M1(TD!DR)UDR)T$C!YAY(P>@"38GC2`GP2(MT)!!)P>L;2#'"08G`3"'J2(VT
M,YEY@EI(,<I(`?),B>9(P>8%3`G>1(T<%DR)[DG![0)(BU0D&$C!YAY,">Y(
MC901F7F"6DR)V4@Q\$&)]DPAX$PQP$C!Z1M(`=!,B=I(P>(%2`G*3(GA2<'L
M`DC!X1Y$C2P"2(GP2(M4)"!,">%,B>Y(,<A)C900F7F"6DC![AM!B<Q,(=A,
M,?!(`=!,B>I(P>(%2`GR1(T$`DR)VDG!ZP)(BT0D*$C!XAY,B<9,"=I)C80&
MF7F"6DC![AM(,=%!B=-,(>E,,>%(`<%,B<!(P>`%2`GP1(TT"$R)Z$G![0)(
MBTPD,$C!X!Y,B?9,">A)C8P,F7F"6D@QPD&)Q4PAPDPQVD@!RDR)\4C!X05(
MP>X;2`GQ3(G&2<'H`DC!YAY$C2012(M4)#A,"<9,B>%(,?!)C903F7F"6DC!
MZ1M!B?!,(?!,,>A(`=!,B>)(P>(%2`G*3(GQ2<'N`DC!X1Y$C1P"2(GP2(M4
M)$!,"?%,B=Y(,<A)C905F7F"6DC![AM!B<Y,(>!,,<!(`=!,B=I(P>(%2`GR
M1(TL`DR)XDG![`)(BT0D2$C!XAY,B>Y,">))C80`F7F"6DC![AM(,=%!B=1,
M(=E,,?%(`<%,B>A(P>`%2`GP1(T$"$R)V$G!ZP)(BTPD4$C!X!Y,B<9,"=A)
MC8P.F7F"6DC![AM(,<)!B<-,(>I,,>)(`<I,B<%(P>$%2`GQ3(GN2<'M`DC!
MYAY$C3012(M4)%A,">Y,B?%(,?!)C904F7F"6DC!Z1M!B?5,(<!,,=A(`=!,
MB?)(P>(%2`G*3(G!2<'H`DC!X1Y$C20"2(GP2(M4)&!,"<%,B>9(,<A)C903
MF7F"6DC![AM!B<A,(?!,,>A(`=!,B>)(P>(%2`GR1(T<`DR)\DB+1"1H2,'B
M'DG![@),B=Y,"?))C80%F7F"6DC![AM(,=%!B=9,(>%,,<%(`<%,B=A(P>`%
M2`GP1(TL"$R)X$G![`)(BTPD<$C!X!Y,B>Y,">!)C8P(F7F"6DC![AM(,<)!
MB<1,(=I,,?)(`<I,B>E(P>$%2`GQ3(G>2<'K`DC!YAY$C0012(M4)'A,"=Y,
MB<%(,?!)C906F7F"6DC!Z1M!B?-,(>A,,>!(`=!,B<)(P>(%2`G*3(GI2<'M
M`DC!X1Y$C30"2(GP2(N4)(````!,">E,B?9(,<A)C904F7F"6DC![AM!B<U,
M(<!,,=A(`=!,B?)(P>(%2`GR1(TD`DR)PDG!Z`)(BX0DB````$C!XAY,B>9,
M"<))C80#F7F"6DC![AM(,=%!B=!,(?%,,>E(`<%,B>!(P>`%2`GP2(NT))``
M``!$C1P(3(GP2<'N`DC!X!Y)C;0UF7F"6DV)W4P)\$G![1M(,<*)P4PAXDPQ
MPD@!\DR)WDC!Y@5,">Z)]D@!\DR)YDG![`)(P>8>08G53`GF3(ND))@```!(
M,?!,(=A/C80@F7F"6DV)[$@QR$G![!M,`<!-B>A)P>`%30G@18G`3`'`38G8
M2<'K`DG!X!Y!B<1-"=A)B?.)]D@#M"2H````33'#1#':3(N<)*````!*C8P9
MH>O9;DV)XT@!T4R)XDG!ZQM(P>(%3`G:B=)(`=%,B>I)P>T"2,'B'D&)RTP)
MZDV)Q46)P$P#A"2P````23'51#'H38G=2(VT!J'KV6Y,B=A)P>T;2,'@!4P)
MZ(G`2`'P3(GF2<'L`DC!YAY!B<5,">9)B=2)TDDQ]$0QX4V)[$@#E"2X````
M38V$"*'KV6Y,B>E)P>P;2,'A!4P)X8G)20'(3(G92<'K`DC!X1Y%B<1,"=E)
MB?.)]D@#M"3`````23'+1#'838GC2(V4`J'KV6Y,B>!)P>L;2,'@!4P)V(G`
M2`'"3(GH2<'M`DC!X!Y!B=-,">A)B<V)R4@#C"3(````23'%13'H38G=3HV$
M!J'KV6Y,B=Y)P>T;2,'F!4P)[HGV3`'&38G@2<'L`DG!X!Y!B?5-">!)B<2)
MP$TQQ$0QXDV)[$B-C!&AZ]EN3(GJ2,'B!4G![!M(`X0DT````$P)XHG22`'1
M3(G:2<'K`DC!XAY!B<Q,"=I-B<-%B<!,`X0DV````$DQTT0QWDV)XTB-M#"A
MZ]EN3(G@2<'K&TC!X`5,"=B)P$@!\$R)[DG![0)(P>8>08G#3`GN28G5B=)(
M`Y0DX````$DQ]40QZ4V)W4V-A`BAZ]EN3(G92<'M&TC!X05,">F)R4D!R$R)
MX4G![`)(P>$>18G%3`GA28GTB?9),<Q$,>!-B>Q(C90"H>O9;DR)Z$G![!M(
MP>`%3`G@B<!(`<),B=A)P>L"2`.T).@```!(P>`>08G43`G828G+B<E(`XPD
M\````$DQPT4QV$V)XTZ-A`:AZ]EN3(GF2<'K&TC!Y@5,"=Z)]DP!QDV)Z$G!
M[0))P>`>08GS30GH28G%B<!(`X0D^````$TQQ40QZDV)W4B-C!&AZ]EN3(G:
M2<'M&TC!X@5,">J)TD@!T4R)XDG![`)(P>(>08G-3`GB38G$18G`23'41#'F
M38GL2(VT,*'KV6Y,B>A)P>P;2,'@!4P)X(G`2`'P3(G>2,'F'DG!ZP)!B<1,
M`X0D``$``$P)WDF)TXG22`.4)`@!``!),?-$,=E-B>--C80(H>O9;DR)X4G!
MZQM(P>$%3`G9B<E)`<A,B>E)P>T"2,'A'D6)PTP)Z4F)]8GV2`.T)!`!``!)
M,<U$,>A-B=U(C90"H>O9;DR)V$G![1M(P>`%3`GHB<!(`<),B>!)P>P"2,'@
M'D&)U4P)X$F)S(G)23'$13'@38GL3HV$!J'KV6Y,B>Y)P>P;2,'F!4P)YHGV
M3`'&38G82<'K`DG!X!Y!B?1-"=A)B<-(`XPD&`$``(G`33'#2`.$)"`!``!$
M,=I-B>-(C8P1H>O9;DR)XDG!ZQM(P>(%3`G:B=)(`=%,B>I)P>T"2,'B'D&)
MRTP)ZDV)Q46)P$P#A"0H`0``23'51#'N38G=2(VT,*'KV6Y,B=A)P>T;2,'@
M!4P)Z(G`2`'P3(GF2<'L`DC!YAY!B<5,">9)B=2)TD@#E"0P`0``23'T1#'A
M38GL38V$"*'KV6Y,B>E)P>P;2,'A!4P)X8G)20'(3(G92<'K`DC!X1Y%B<1,
M"=E)B?.)]DDQRT0QV$V)XT@#M"0X`0``2(V4`J'KV6Y,B>!)P>L;2,'@!4P)
MV$2-'!!,B>A)P>T"2,'@'DP)Z$F)S8G)23'%B<)%,>A-B=U.C80&H>O9;DR)
MWDG![1M(P>8%3`GN3(NL)$`!``!&C30&38G@2<'L`DG!X!Y-">!,"<!$B<9)
MB<1(B=!((?!-(=Q)"<2XW+P;CTD!Q4P!Z4V)]4D!S$R)\4G![1M(P>$%3`GI
M28GU00',3(G92<'K`DC!X1Y,"=E!B<M)"<A-(?!-(=U-">A,BZPD2`$``$D!
MQ4P!ZDV)Y4D!T$R)XDG![1M(P>(%3`GJ1HTL`DR)\DG![@)(P>(>3`GR38G>
M08G02`G132'&3"'A3`GQ3(NT)%`!``!)`<9,`?9-B>Y(`?%,B>Y)P>X;2,'F
M!4P)]D2--`Y,B>9)P>P"2,'F'DP)YDV)Q(GQ2`GR22',3"'J3`GB3(ND)%@!
M``!)`<1-`>--B?1,`=I-B?-)P>,%2<'L&TT)XT6-)!--B>M)P>T"2<'C'DT)
MZTF)S42)VDP)WDDAU4PA]DP)[DR+K"1@`0``20'%30'H38GE3`'&38G@2<'M
M&TG!X`5-">A%C2PP38GP2<'N`DG!X!Y-"?!)B=9$B<9-"<-)(?9-(>--"?-,
MB[0D:`$``$D!QDP!\4V)[DD!RTR)Z4G![AM(P>$%3`GQ1HTT&4R)X4G![`)(
MP>$>3`GA28GT08G+20G(32'H32'<30G@3(ND)'`!``!)`<1,`>)-B?1)`=!,
MB?))P>P;2,'B!4P)XD:-)`),B>I)P>T"2,'B'DP)ZDV)W4&)T$@)T4TAQ4PA
M\4P)Z4R+K"1X`0``20'%3`'N38GE2`'Q3(GF2<'M&TC!Y@5,">Y$C2P.3(GV
M2<'N`DC!YAY,"?9-B<:)\4@)\DDASDPAXDP)\DR+M"2``0``20'&30'S38GN
M3`':38GK2<'C!4G![AM-"?-%C30338GC2<'L`DG!XQY-">-)B<Q$B=I,"=Y)
M(=1,(>Y,">9,BZ0DB`$``$D!Q$T!X$V)]$P!QDV)\$G![!M)P>`%30G@18TD
M,$V)Z$G![0))P>`>30GH28G51(G&30G#22'U32'S30GK3(NL))`!``!)`<5,
M`>E-B>5)`<M,B>%)P>T;2,'A!4P)Z4:-+!E,B?%)P>X"2,'A'DP)\4F)]DD)
MR$&)RTTAWDTAX$T)\$R+M"28`0``20'&3`'R38GN20'03(GJ2<'N&TC!X@5,
M"?)&C30"3(GB2<'L`DC!XAY,">)-B=Q!B=!("=%-(<1,(>E,">%,BZ0DH`$`
M`$D!Q$P!YDV)]$@!\4R)]DG![!M(P>8%3`GF1(TD#DR)[DG![0)(P>8>3`GN
M38G%B?%("?))(<U,(?),">I,BZPDJ`$``$D!Q4T!ZTV)Y4P!VDV)XTG![1M)
MP>,%30GK18TL$TV)\TG![@))P>,>30GS28G.1(G:3`G>22'63"'F3`GV3(NT
M)+`!``!)`<9-`?!-B>Y,`<9-B>A)P>X;2<'@!4T)\$6--#!-B>!)P>P"2<'@
M'DT)X$F)U$2)QDT)PTDA]$TAZTT)XTR+I"2X`0``20'$3`'A38GT20'+3(GQ
M2<'L&TC!X05,">%&C2093(GI2<'M`DC!X1Y,">E)B?5!B<M)"<A-(?!-(=U-
M">A,BZPDP`$``$D!Q4P!ZDV)Y4D!T$R)XDG![1M(P>(%3`GJ1HTL`DR)\DG!
M[@)-B=A(P>(>3`GR08G62`G132'P3"'A3`G!3(N$),@!``!)`<!,`<9-B>A(
M`?%,B>Y)P>@;2,'F!4P)QD2-!`Y,B>9)P>P"3(GQ2,'F'DP)YD&)]$@)\DPA
MX4PAZD@)RDB+C"30`0``2`'!20'+3(G!2`.$)-@!``!,`=I-B<-(P>$%3`'P
M2<'K&TP)V8G)2`'*3(GI2<'M`DC!X1Y!B=-,">E-B>5!B<]("<Y-(?U,(<9,
M">Y-B=U(`?!,B=Y)P>T;2,'F!4P)[HGV2`'P3(G&2<'H`DC!YAY!B<5)"?"^
MUL%BRDPQP3'*2(N,).`!``!(`?%)`<Q,B>E,`>)-B>Q(P>$%2<'L&TP)X8G)
M2`'*3(G92,'A'DG!ZP)!B=1)"<M,B<%-B>9%B<!,,=E)P>X;,<A(BXPDZ`$`
M`$@!\4D!STJ-##A,B>!(P>`%3`GPB<!,C30!3(GH2<'M`DR)V4C!X!Y%B?=%
MB=M)"<5(BX0D\`$``$PQZ4@!\#'*3(GY3`'`2,'I&T@!PDR)^$C!X`5("<A(
MBXPD^`$``(G`2`'"3(G@2`'Q2<'L`DC!X!Y,`=E-B>M!B=!,">!-B<1%B>U)
M,<-)P>P;13'>3HT<,4R)P4C!X05,">&)R4D!RTR)^4G![P)(P>$>18G<20G/
M2(N,)``"``!(`?%,`>E)B<6)P$TQ_40QZDR-+!%,B>),B>%(P>D;2,'B!4@)
MRDR)P4G!Z`*)TDC!X1Y)`=5(BY0D"`(``$P)P4V)^$DQR$6)[D6)_T@!\D4Q
MPT@!T$R)\DZ-!!A,B?!(P>H;2,'@!4@)T$B)RHG)B<!)`<!,B>!)P>P"2,'@
M'D6)PTD)Q$B+A"00`@``3#'B2`'P03'53(G:3`'X20'%3(G82,'@!4C!ZAM(
M"=!,B?))P>X"B<!(P>(>20'%2(N$)!@"``!,"?)%B>](`?!(`<A,B>%%B>1(
M,=%!,<A,B?E)`<!,B?A(P>D;2,'@!4@)R(G`20'`3(G82<'K`DC!X!Y%B<9)
M"<-(BX0D(`(``$R)\4C!Z1M(`?!,`>!)B=2)TDTQW$4QY4Z-)"A,B?!(P>`%
M2`G(2(N,)"@"``")P$D!Q$R)^$@!\4G![P)(P>`>2`'*3(G918GE3`GX18G;
M2#'!03'(3(GI20'03(GJ2,'I&TC!X@5("<J)TDD!T$R)\DG![@)(P>(>18G'
M20G62(N4)#`"``!,B?E(P>D;2`'R3`':28G#B<!-,?-%,=Q.C1PB3(GZ2,'B
M!4@)RDR)Z4G![0*)TDC!X1Y)`=-(BY0D.`(``$P)Z46)W$@!\D@!T$R)\D6)
M]D@QRD$QT$R)XDD!P$R)X$C!ZAM(P>`%2`G02(G*B<F)P$D!P$R)^$G![P)(
MP>`>18G%20G'2(N$)$`"``!(`?!,,?I,`?!!,=-,B>I)`<-,B>A(P>H;2,'@
M!4@)T$R)XDG![`*)P$C!XAY)`<-(BX0D2`(``$P)XD6)WDF)U$@!\$@!R$R)
M^46)_T@QT8G203'(2HT,`$R)\$V)\$G!Z!M(P>`%3`G`B<!(`<%,B>A)P>T"
M2,'@'D&)R$D)Q4B+A"10`@``33'L2`'P13'C38G$3`'X2<'L&TD!PTR)P$C!
MX`5,">")P$D!PTR)\$C!X!Y)P>X"18G<3`GP3(NT)%@"``!)`?9)`=9,B>I%
MB>U(,<(QT4F-%`Y,B>%-B>9)P>X;2,'A!4P)\8G)2`'*3(G!2<'H`DC!X1Y!
MB=9)"<A(BXPD8`(``$@!\4P!Z4F)Q8G`33'%13'K38GU20'+3(GQ2<'M&TC!
MX05,">F)R4D!RTR)X4G![`)(P>$>18G=20G,2(N,)&@"``!(`?%(`<A,B<%%
MB<!,,>$QRDB-#!!,B>A,B>I(P>H;2,'@!4@)T$R)\DG![@)(P>(>B<!)"=9(
MBY0D<`(``$@!P8G(2`'R3`'"38G@33'P13'#28G`3`':28G#2<'@!4G!ZQM-
M"=A)B<-(P>@"2<'C'D$!T$R)ZDG![0))"<-(BX0D>`(``$C!XAY)"=5$B>)!
M`=M(`?!$`>U,B5\02`'"3(GP2(EO&$PQZ#'!2(T$"DR)PDR)P44!R$C!X@5(
MP>D;3(E'"$@)R@'000'"1`-W($R)%TR)=R!(BX0DB`(``&1(,P0E*````'42
M2('$F`(``%M=05Q!74%>05_#Z*KE__]F+@\?A```````05=!5D%505154TB#
M[`A(A?\/A+$```!(BP5R@@``3(LX387_#X2>````#[8'A,!T!#P]=5M%,>1)
MBQ](A=MT-DF)]4F)_DUCY$R)_0\?0`!,B>),B?9(B=_H8N/__X7`=0="@#PC
M/71'2(/%"$B+70!(A=MUVDB#Q`A(B=A;74%<05U!7D%?PP\?A```````28G\
M28/$`4$/M@0DA,!T!#P]=>]!*?SKCP\?@`````!,*?U*C5PC`4C!_0-!B6T`
MZ[1F#Q]$```QV^NJ#Q]``%5(B?U32(/L&&1(BP0E*````$B)1"0(,<!(C5PD
M!&:0,<!(B=Y(B>_H`____TB%P'0^2(L%AX$``$AC5"0$2(L`2(T$T$B+4`A(
MB1!(A=)TSP\?@`````!(@\`(2(M0"$B)$$B%TG7PZ[9F#Q]$``!(BT0D"&1(
M,P0E*````'4'2(/$&%M=P^A$Y/__#Q]``$%7059!54%454B)]5-(B?M(@^PH
M9$B+!"4H````2(E$)!@QP#'`@#X]#Y3`2`'%2(GOZ/GB__](C70D%$B)WTF)
MQ#'`Z%?^__](A<`/A`X!``!(B<=)B<7HT^+__TPYX`^#V@```$AC3"043(LM
MOH```$C!X0,/M@.$P`^$KP$``#P]#X2G`0``2(G8#Q]``$B#P`$/MA"$TG0%
M@/H]=?!(*=A(F$D#30!*C7P@`DF)SNBZX?__28D&2(7`#X2"`0``28M%`$AC
M5"042(U+`4B+%-`/M@.(`CP]="*$P'4,ZQQF#Q]$```\/7022(/!`0^V0?](
M@\(!B`*$P'7JQ@(],<`/'T0```^V3`4`B$P"`4B#P`&$R77O,<!(BUPD&&1(
M,QPE*`````^%'P$``$B#Q"A;74%<05U!7D%?PV:0,<!F#Q]$```/ME0%`$&(
M5`4`2(/``832=>[KO0\?0`!,BRW)?P``38M]`$F#/P`/A,(```!,B?@QTNL'
M#Q]``$2)\DB#P`A$C7(!2(,X`'7OC7(#2&/V2,'F`XL%'Y(``(7`=6/'!1&2
M```!````2(GWZ+G@__](A<`/A(0```!-8\Y,B?Y(B<=*C0S-`````$R)3"0(
M2(G*2(D,).CNX?__3(M,)`A(BPPD28E%`$F)P$O'1,@(`````$2)="04Z7'^
M__\/'P!,B?_HX.+__TF)P$F)10!(A<!T*$UCSDJ-#,T`````Z\D/'X``````
M,<#I;O[__[X0````13'VZ5?___^X_____^G-_O__Z.WA__]F9BX/'X0`````
M`&:005=!5D%505154TB![+@```!D2(L$)2@```!(B80DJ````#'`2(7_=`B`
M/P!(B?MU+TB+A"2H````9$@S!"4H````#X4O`0``2('$N````%M=05Q!74%>
M05_#9@\?1```Z'O@__](B<5(A<!TQ$B-1"003(TEK!X``$B)1"0(3(TUGQX`
M`$B)[^A#XO__2(7`#X3"````3(UX$[D"````3(GG3(G^\Z8/E\`<`(3`=-6Y
M`P```$R)_DR)]_.F#Y?`'`"$P'2_2(G?Z`+@__],B?])B<7H]]___T&-?`4"
M2&/_Z"K?__]-B?E)B=B^`0```$F)Q4B)QS'`2,?"_____TB-#2`>``#H9.'_
M_TB+5"0(OP$```!,B>[H$N'__TR)[X/X_W00BT0D*"4`\```/0!```!T.N@5
MW___3(GOZ'W?__](B>_HA>'__TB%P`^%0O___P\?0`!(B>_H`.'__TB)W^CX
MWO__Z<3^__\/'P#HB_[__^O$Z&3@__\/'T``4TB)_DB)^[\!````2('LH```
M`&1(BP0E*````$B)A"28````,<!(B>+HXM___X7`=3:+5"08@>(`\```@?H`
M0```=`B!^@"@``!U'KX"````2(G?Z*?@__^%P`^4P`^VP.L'#Q]$```QP$B+
MC"28````9$@S#"4H````=0E(@<2@````6\/HU=___P\?1```05:Z_P\``$F)
M]D%5051)B?Q(C3T%'0``55-(@>P0$```9$B+!"4H````2(F$)`@0```QP$B)
MXTB)WN@!W___A<!^=8U0_TB+#6M\``!(8^J`/"P`1(LI=5>%TG1E2(GJOB\`
M``!(B=_H,]W__TB%P'101(GOZ,;<__](B>E(B=I,B>9(B<?HI=[__TB+A"0(
M$```9$@S!"4H````=3Q(@<00$```6UU!7$%=05[#9I!(8^CKJ`\?`$B+!?E[
M``!$BRA$B>_H=MS__TR)\DR)YDB)Q^B(W?__Z['H\=[__Y!(@^P(2(L%S7L`
M`(LXZ$[<__](BQ7W>P``2(/$"$B-#00>``!(C34A'```2(G'Z7W?__]F9BX/
M'X0``````&:04TB+'9![``"+.^@1W/__2(G'Z*G___^+.^@"W/__3(T%<1T`
M`$4QR5M(Q\+@5D``3(G!2(TU[AL``$B)Q^F.W?__9F8N#Q^$```````/'P!5
M4TB!["@@``!D2(L$)2@```!(B80D&"```#'`2(GC2(VL)!`0``#HY-S__TB-
M#;H;``"Z`1```$B)WT&)P$R-#7,;``"^`0```#'`Z)_>__^Z`!```$B)[DB)
MW^AOW?__,<F%P'@NC7@!2(G#2&/_Z!O<__](B<%(A<!T&$ACVTB)[DB)QTB)
MVNBRWO__Q@08`$B)P4B+E"08(```9$@S%"4H````2(G(=0I(@<0H(```6UW#
MZ*;=__]F#Q]$``#I.____V9F+@\?A```````05=!5D%5051)B?152(G]2(T]
M$QL``%-(@>RX$```9$B+!"4H````2(F$)*@0```QP$B-="0,Z+7W__^^+P``
M`$B)[TB)P^CEW/__2(7`=$!(B>Y(C3W8&@``,<#H[_C__TB)Z$B+C"2H$```
M9$@S#"4H````#X6"`0``2('$N!```%M=05Q!74%>05_##Q\`2(GOZ.C;__](
MC36@&@``3(GG08G%Z`;=__])B<=(A<!TGD&#Q0%!@#\`3(UT)!!,C:0DH```
M``^$R0````\?`$B%VW033(G^2(G?Z,#<__^%P`^$B@```$R)_^B0V___B<)(
MF$&`?`?_+W47#Q]``(/J`4ACPD&`?`?_+T'&!`<`=.U$`>J!^O\/```/CR[_
M__](@^P(2(T-^AH``$V)^#'`54R-#0<:``"Z`!```$R)Y[X!````Z-3<__],
MB?),B>:_`0```.B$W/__6EF%P'40BT0D*"4`\```/0"```!T7DB--<89```Q
M_^@PW/__28G'2(7`#X3$_O__08`_``^%.O___TB%VW0=N0(```!(B=Y(C3TK
M&0``\Z8/E\`<`(3`=+T/'P!,C3T6&0``N@$```#I2O___P\?@`````"^`0``
M`$R)Y^A3W/__A<!UD4R)YDB-/4<9``#H8/?__TR)Y^AXV___Z6?^___HCMO_
M_V9F+@\?A```````#Q\`#[872(GXA-)T'F8/'T0``$B#QP&`^B\/MA=(#T3'
MA-)U[L,/'T0``,,/'X``````2(7_#X2G````@#\`#X2>````4TB)^^@EVO__
M2(U4`_](.=-R%.LG9@\?A```````2(/J`4@YTW0:@#HO=/+K!8`Z+W0H2(/J
M`4@YTW+R2#G3=1J`.B]T:$B-/:(8``!;Z<O:__\/'P"`.B]U"4B#Z@%(.=-R
M\D@IVC'`2(U*`DB!^0`0``!W'TB#P@&Y`!```$B)WDB-/35Z``#H4-C__TB-
M!2EZ``!;PP\?@`````!(C3W>%P``Z73:__\/'T``2(T]SA<``%OI8]K__P\?
M`%-(C3TK&```2(/L0/,/;P5\&0``\P]O#809``!D2(L$)2@```!(B40D.#'`
M#[<%?1D``$B-7"0,#RE$)!!FB40D,#'`#RE,)"#H8O7__S'`2(T]Y1<``.A4
M]?__,<!(C3W?%P``Z$;U__\QP$B-/=H7``#H./7__S'`2(T]TQ<``.@J]?__
M,<!(C3W5%P``Z!SU__\QP$B-/7P7``#H#O7__S'`2(T]Q1<``.@`]?__,<!(
MC3W!%P``Z/+T__\QP$B-/;T7``#HY/3__S'`2(T]31<``.C6]/__,<!(B=Y(
MC3VH%P``Z/7S__](A<!T$4B)QDB-/8`7```QP.@_]?__,<!(B=Y(C3V2%P``
MZ,[S__](A<!T$4B)QDB-/9`7```QP.@8]?__,<!(B=Y(C3V(%P``Z*?S__](
MA<!T0DB)QDB-/=$6```QP.CQ]/__,<!(C360%P``2(T]]18``.C<]/__2(M$
M)#AD2#,$)2@```!U;DB#Q$!;PV8/'T0``#'`2(G>2(T]0!<``.A/\___2(7`
M=!I(B<9(C3W0%@``,<#HF?3__^NF#Q^``````$B-="0AN0H```!(C3T<%P``
M\Z8/E\`<`(3`=8-(C70D*TB-/9@6``#H8_3__^EM____Z)G8__]F#Q^$````
M``!(@^P89$B+!"4H````2(E$)`@QP(L%MG<``(/X_W092(M\)`AD2#,\)2@`
M``!U0$B#Q!C##Q]``$B-="0$2(T]/!8``#'`Z*7R__](B<(QP$B%TG02#[82
M@/HP#Y7!,<"$T@^5P"'(B05C=P``Z[#H'-C__V9F+@\?A```````D$B#[`CH
M-]C__XG'Z,#6__](A<!T"TB+`$B#Q`C##Q\`,<!(@\0(PV8/'X0``````$%4
M54B)_4B-/;D6``!32(/L$&1(BP0E*````$B)1"0(,<!(C70D!.@4\O__2(GN
M2(7`=`B`.`!(B<-U+$B-/8,6```QP.A6\___2(M$)`AD2#,$)2@```!U?TB#
MQ!!;74%<PP\?1```2(G'Z,#6__](A<!UU4B)[^A3UO__2(G?28G$Z$C6__])
MC7P$`NA^U?__2(/L"$F)Z+X!````4TC'PO____](B<=)B<1,C0W<%```2(T-
MO14``#'`Z*_7__],B>9(C3W[%0``,<#HSO+__UA:Z7'____H`M?__V:005=)
MB?](C3V-%```059!54%455-(@>R8@0``9$B+!"4H````2(F$)(B!```QP$B-
M!4$5``!,C60D+$C'1"1``````$B)1"0P2(T%]A,``$R)YDB)1"0X2(T%TQ0`
M`$B)1"1P2(T%P!0``$B)1"1X2(T%!14``$B)A"2`````2(T%PA0``$B)A"2(
M````2(T%[Q0``$B)A"20````2(T%QQ0``$B)1"102(T%V!0``$B)1"18,<!(
MQX0DF`````````!(QT0D8`````#HD/#__TB%P'0)@#@`#X7*!```,<#H"_[_
M_TB)PTB%P`^$/P0``$B)W^CWU/__2(U\``'H+=3__X`[`$F)Q70W3(GM3(TU
M>Q0```\?`$0/M@-(B>\QP$R)\4C'PO____^^`0```$B#PP%(@\4"Z%/6__^`
M.P!UUDB-7"1P2(T]XQ,``.L02(/#"$B+.TB%_P^$H`$``$R)YC'`Z/;O__](
MB<5(A<!TWH`X`'392(G'Z"'U__^%P'3-2(GOZ%75__])B<9(A<`/A&D!``!F
M#Q^$``````!,B?&+$4B#P02-@O_^_O[WTB'0)8"`@(!TZ8G"P>H0J8"````/
M1,)(C5$"2`]$RHG"`,),B>I(@]D#3"GQBS)(@\($C8;__O[^]]8A\"6`@("`
M=.F)QL'N$*F`@```#T3&2(UR`D@/1-:)QD``QDB#V@-,*>J-G!$$!```2&/;
M2(G?Z`G3__]!54V)\+X!````2(G%2(T%8Q,``$R-#6\2``!(Q\+_____4$B-
M#403``!(B>\QP.@UU?__OL`!``!(B>_HF-7__T%805F#^/]U$NA:U/__1(L(
M08/Y$0^%]@(``$R-K"2@````2(GNOP$```!,B>KH%=3__T&)QH7`#X2Z````
M2(L%@W$``$F+#TF)Z#';2(T5S!,``+X!````2(LX,<#H%=+__TB+C"2(@0``
M9$@S#"4H````2(G8#X4V"```2('$F($``%M=05Q!74%>05_#9@\?A```````
M,>UF#Q]$``!(8\5(BUS$,$B%VW0[@#L`=#9(B=^#Q0'H>_/__X7`=-](B=_H
MK]/__TF)QDB%P`^%8_[__TACQ4B+7,0P2(7;=<MF#Q]$``!%,?;I2/[__P\?
MA```````BX0DN````"4`\```/0!````/A2____^+A"2\````B00DZ*K3__\Y
M!"0/A1?___^+A"2X````)?\!```]P`$```^%`/___TB)W^B"T?__3(GF2(T]
MZQ$``$B)PS'`Z)[M__](A<`/A!T"``!(B<?H#=/__TF+/TB)QNB2]?__28G$
M2(7`#X3^`0``3(GGZ/[1__^#^`-^04ACT+D%````2(T]HA$``$F-=!3\\Z8/
ME\*`V@"$TG4A@_@$#X2H!0``@^@$2)A!@'P$_R\/A)<%```/'X``````,<#H
M,?K__X7`=14Q]DR)Y^CST?__B00DA<`/A9@!``!(C34)$0``2(T]BA```#'`
MZ%/N__],C25R$0``3(TM-A```.@PT?__051)B>B^`0```%!(Q\+_____2(G?
M,<!,C0T3$```2(T-'!$``.CFTO__6%KK16:0Z!O2__^#.!%U2^CQT/__08/&
M`4B#[`A-B>E!5$F)Z$B-#?D0``!(B=]!5DC'PO____^^`0```%`QP.BATO__
M2(/$(+[``0``2(G?Z`#3__^#^/]TJTB)[^C3T/__2(G>2(T]@@\``#'`Z*+M
M__](B=_H^OG__^F@_?__#Q]$``!(C3TS$```,>WK#0\?1```2&/%2(M\Q%!(
MA?]T>TR)YC'`@\4!Z`;L__](A<!TX8`X`'3<2(G'Z'31__](B<-(A<!TS.EX
M^___2(L%L&X``$F+#TF)Z#';2(T5N1```+X!````2(LX,<#H0L___^DH_?__
M#Q]$``!(B<=(B00DZ&SY__](BP0D2(G'Z"#1__](B</I`_W__[\-````2(T=
MFP\``.A7S___28G%Z2K[__\/'X``````38LGZ?K]__^Z`@```$C'QN[___]!
MB<>)Q^AJT?__3(VT)(`!``"Z!@```$2)_TR)]NCRSO__@+PD@`$```!U#H"\
M)($!``!##X1<!```BSPD,=(Q]N@NT?__N(FKS>](QX0DH`````$C16=(B80D
MJ````$@MB\X25TB)A"2P````2`7R!!@K2(F$),````!)C44X2,>$)+@```!V
M5#(02,>$),@`````````2,>$)-``````````QX0D&`$```````!(B40D$)"+
M/"2Z`(```$R)]NA0SO__2(G!08G`A<`/CF(!``!(B[PDR````$ACP4B+E"30
M````C33'2#G^2(FT),@```!(@](`2,'H'4@!T$B)A"30````2&.$)!@!``"%
MP`^$%@$``$&X0````$B)3"0(3(GV02G`1#G!1`].P4B+3"0036/X2(T\`4R)
M^NBBT/__BX0D&`$``$B+3"0(1`'X@_A`B80D&`$```^%4____T&)R$R)[T4I
M^$T!]T2)1"0(Z,W3__]$BT0D"$&#^#\/CH@"``!!C4#`B40D','H!D&)Q(E$
M)`A)@\0!2<'D!DT!_)#S00]O#_-!#V]7$$R)[TF#QT#S00]O7^#S00]O9_`/
M$8PDV`````\1E"3H````#Q&<)/@````/$:0D"`$``.A=T___33GG=;B+1"0(
M1(M$)!S!X`9!*<!(BWPD$$ECT+E(````3(GF1(E$)`CHC\W__T2+1"0(1(F$
M)!@!``#IC?[__P\?1```38GWZ4C___^+/"3H>,S__TB+A"3(````1(ND),@`
M``!$B[0DT````$C!Z`-!#\R#X#]!#\Z-4`%(F,:$!-@```"`@_HX#XZ?`0``
MN$````!(8\HIT$F-=`TXB<)T#S'`B<&#P`'&!`X`.=!R\TR)[^BCTO__9@_O
MP`\1A"38````2<=%:`````!!#Q%%2$$/$4583(GO1(FT)!`!``!,C;PD,0$`
M`$R-M"1X`0``1(FD)!0!``!,C2VK#```Z%;2__^+A"2@````1`^VA"2C````
M#\B)A"0P`0``BX0DJ`````_(B80D-`$``(N$)+`````/R(F$)#@!``"+A"2X
M````#\B)A"0\`0``BX0DP`````_(B80D0`$``$B-A"10`0``2(D$)$F)Q.L,
M#Q]``$4/M@=)@\<!3(GG10^VP$R)Z;X!````2,?"_____S'`28/$`N@/SO__
M33GF==)(C059#```QH0D>`$```!0_W0D"$B-#1$,``!)B>A(B=\QP+X!````
M3(T-_`H``$C'PO_____HS\W__UE>Z3W[__]-BW\(387_#X1C^O__3(G_Z!/,
M__](@_@##X91^O__28UT!_RY!0```$B-/;4+``#SI@^7P!P`A,!-#T3GZ2[Z
M__]-B?SIY?W__[@X````,?\IT$ACTDF-5!4X@_@(<RBH!`^%V````(7`#X2#
M_O__Q@(`J`(/A'C^__\Q_V:)?`+^Z6S^__^0B<%(QP(`````2,=$"O@`````
M2(U*"$B#X?A(*<H!T(/@^(/X"`^"0/[__X/@^#'2B=:#P@A(B3PQ.<)R\^DI
M_O__@+PD@@$``$$/A9;[__^`O"2#`0``0P^%B/O__X"\)(0!``!(#X5Z^___
M@+PDA0$``$4/A6S[__]$BSPDN@(```!(Q\;&____1(G_Z([,__^Z*0```$R)
M]D2)_^@>RO__2(T%[0H``%!!5NF9_O__#Q^``````,<"`````,=$`OP`````
MZ:#]___HX,O__T%7059!54%455-(@^PH2(LMLV@``&1(BP0E*````$B)1"08
M,<"+?0#H(\G__XM]`$B)P^@8R?__#[:3N````$B-/6X)``"(D+D```!(C40D
M%$B)1"0(2(G&,<#HX.7__TB%P'0)@#@Q#X3B`@``,<#HZ_#__XM]`.C3R/__
MN0L```"Z`0```$B--3(*``!(B<?HJLG__TB%P`^$N0```$B+0!"#/<9Z```!
M1(M]`$R+:"@/CJ0````QV^LW#Q]``$F+=A!(BPV=>@``26/42(L\T>@9R___
MBQ63>@``A<`/A?4!``"#PP(YTT2)XP^-YP$``$2)_T2-8P'H4<C__S')2&/3
M3(GN2(G'Z%'*__](A<`/A+@!``!,BS!$BWT`08M&#"4`!"``/0`$``!TD42)
M_^@9R/__3(GVN0(````QTDB)Q^BGR___1(M]`$B)QNEO____#Q\`1(M]`$2)
M_^CLQ___N0,```"Z`0```$B--5`)``!(B<?HP\C__TB)PTB%P'0R2(M`$(M]
M`$R+(.B\Q___2(T5+`D``$B)QTR)YNC*R/__2(M#$$B+&/9##D`/A=(!``"+
M?0#HD<?__[D#````N@$```!(C37\"```2(G'Z&C(__](B<-(A<!T/$B+="0(
M2(T]E@<``#'`Z$WD__])B<1(A<`/A&$!``!(BT,0BWT`2(L8Z$+'__],B>)(
MB=Y(B<?H5,C__XM]`.@LQ___N@$```!(C36>"```2(G'Z#C'__^+?0!(B</H
M#<?__TB)WDB-%98(``!(B<?H&\C__XM]`.CSQO__2(MT)`A(C3T0!P``QH"Y
M`````#'`Z,GC__](B<-(B07W>```2(7`#X26````OL`!``!(B=_H2<K__XU0
M`8/Z`78)@_@1#X7^````2(M$)!AD2#,$)2@````/A>4```!(@\0H6UU!7$%=
M05Y!7\,/'T0``(L5FG@``$2+?0"-0O\YV`^%=_[__X/Z`0^.;O[__[L!````
M#Q]$``!$B?^#PP'H3<;__TR)[DB)Q^@BQ___.1U<>```1(M]`'_>Z3W^__^0
M2(L]07@``.BT\?__2(G#2(D%0G@``$B%P`^%2____TB-/7H(```QP.C3R/__
M#Q\`@'@!``^$&_W__^D/_?__D$B+!0%X``"+?0!,BR!(BT,02(L8Z-?%__],
MB>9(B=_HC.C__^F3_O__BWT`Z+_%__](B=Y(B<?H-,C__^D6_O__Z#K(__^)
MP4B+!;EW``!(B=I(C3TO"```2(LP,<#H7<C__V9F+@\?A```````9I!54TB)
M^TB#[`CHLNS__TB)Q^AZ[/__2(G%,<#H8.___X7`="1(A=MT'X`[`'0:N00`
M``!(C3UT!@``2(GN\Z8/E\`<`(3`=`A(@\0(6UW#D$B#Q`A(B=];7>G2Y?__
M9I#S#Q[Z05=)B==!5DF)]D%508G]051,C24\8@``54B-+3QB``!33"GE2(/L
M".B_Q/__2,']`W0?,=L/'X``````3(GZ3(GV1(GO0?\4W$B#PP%(.=UUZDB#
MQ`A;74%<05U!7D%?PV9F+@\?A```````\P\>^L-F+@\?A```````D/,/'OI(
MBPU=9@``Z2#%___S#Q[Z2(/L"$B#Q`C#````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````0`"`"XN`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D97(Z
M.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E
M:2\E<P!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,
M24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%
M1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%
M0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]4
M14U0`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,14%./0`Q`%5315(`4UE35$5-
M`"]T;7``5$5-4$1)4@!435``55-%4DY!344`)3`R>``E<R5S)7,E<P!P87(M
M`%!!5$@`<&%R;``N<&%R`"5S)7-C86-H92TE<R5S`"5S)7-T96UP+25U)7,`
M)7,E<W1E;7`M)74M)74E<P!!4D=6`!@`<&5R;``P`%!!4CHZ4&%C:V5R.CI6
M15)324].`#$N,#0U`"UE`"TM``!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@
M("`@("`@(```````````<&5R;'AS:2YC`````````"5S.B!C<F5A=&EO;B!O
M9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`
M```````E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP
M;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*````
M````56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD``````````"5S
M.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F
M86EL960@*&5R<FYO/25I*0H``````````&5V86P@)V5X96,@+W5S<B]B:6XO
M<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N
M9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1P87)?=&5M
M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#
M3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A
M<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE
M.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q>U)E;6]V
M:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D["D9I;&4Z.D9I;F0Z.F9I;F1D
M97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E
M;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/
M(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%
M35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ
M9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^
M(#`L"BD["G!R:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X
M("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G
M)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<
M)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@+B`B)PHB.PIC
M:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PIM>2`D8VUD(#T@)'1M<"T^9FEL
M96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*8VQO<V4@)'1M<#L*<WES
M=&5M*"1C;60I.PIO=71S*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S
M('1O('!E<F9O<FT@8VQE86YU<#H@*0HN("1T;7`M/F9I;&5N86UE*3L*?0I]
M('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@
M)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I
M.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N9FEG(#T@
M*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG
M*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W
M:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O
M7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I
M.PI?<V5T7W!A<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I
M.PI["FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIO<&5N(%]&2"P@
M)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F
M.PIM>2`D<VEZ92`]("US("1P<F]G;F%M93L*;7D@)&]F9G-E="`](#4Q,CL*
M;7D@)&ED>"`]("TQ.PIW:&EL92`H,2D*>PHD;V9F<V5T(#T@)'-I>F4@:68@
M)&]F9G-E="`^("1S:7IE.PIS965K(%]&2"P@+21O9F9S970L(#(@;W(@9&EE
M('%Q6W-E96L@9F%I;&5D(&]N("(D<')O9VYA;64B.B`D(5T["FUY("1N<F5A
M9"`](')E860@7T9(+"`D8G5F+"`D;V9F<V5T.PID:64@<7%;<F5A9"!F86EL
M960@;VX@(B1P<F]G;F%M92(Z("0A72!U;FQE<W,@)&YR96%D(#T]("1O9F9S
M970["B1I9'@@/2!R:6YD97@H)&)U9BP@(EQN4$%2+G!M7&XB*3L*;&%S="!I
M9B`D:61X(#X](#`@?'P@)&]F9G-E="`]/2`D<VEZ92!\?"`D;V9F<V5T(#X@
M,3(X("H@,3`R-#L*)&]F9G-E="`J/2`R.PI]"FQA<W0@=6YL97-S("1I9'@@
M/CT@,#L*)&]F9G-E="`M/2`D:61X("T@-#L*<V5E:R!?1D@L("TD;V9F<V5T
M+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*<V5E:R!?1D@L("TD;V9F<V5T("T@
M=6YP86-K*").(BP@)&)U9BDL(#(["G)E860@7T9(+"`D8G5F+"`T.PHD9&%T
M85]P;W,@/2`H=&5L;"!?1D@I("T@-#L*;7D@)7)E<75I<F5?;&ES=#L*=VAI
M;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D
M(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]
M("1B=68["F]U=',H<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI
M*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\
M?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U
M9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@
M-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F
M:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI
M('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8W)C)&5X="(L("1B=68L
M(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D
M9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]
M("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB
M+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M
M92`](%]T96UP9FEL92@B)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO
M=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*)')E<75I<F5?
M;&ES='LD9G5L;&YA;65](#T*)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F
M=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]
M/B`D9G5L;&YA;64L"GT["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@
M0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R
M;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&9I;&5N86UE(#T@
M9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@?'P@9&\@>PIM>2`D:V5Y
M.PIF;W)E86-H("AK97ES("5R97%U:7)E7VQI<W0I('L*;F5X="!U;FQE<W,@
M+UQ1)&UO9'5L95Q%)"\["B1K97D@/2`D7SL@;&%S=#L*?0ID96QE=&4@)')E
M<75I<F5?;&ES='LD:V5Y?2!I9B!D969I;F5D*"1K97DI.PI](&]R(')E='5R
M;CL*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE
M(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z
M.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I
M92`D(3L*8FEN;6]D92@D9F@I.PIP<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F
M?3L*<V5E:R@D9F@L(#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D
M9FEL96YA;64@/2!?=&5M<&9I;&4H(B1F:6QE;F%M92T^>V-R8WTN<&TB+"`D
M9FEL96YA;64M/GMB=69]*3L*;W!E;B!M>2`D9F@L("<\)RP@)&9I;&5N86UE
M(&]R(&1I92`B8V%N)W0@<F5A9"`D9FEL96YA;64Z("0A(CL*8FEN;6]D92@D
M9F@I.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z
M(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PI]+"!`24Y#*3L*<F5Q=6ER92!8
M4TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE
M879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@
M)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU
M;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!
M3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@
M)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE
M;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q
M=6ER95]L:7-T>R1F:6QE;F%M97T["GT*;&%S="!U;FQE<W,@)&)U9B!E<2`B
M4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L*?0IM
M>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H
M95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I
M>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`]
M(#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R
M("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY
M("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?
M<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y
M7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@
M>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!
M4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D
M7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-
M3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*
M<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE
M=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`
M<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R
M.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE
M;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H
M)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@
M>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O
M<&5N(&QO9SH@)"$B.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA
M;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?
M8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H
M*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@
M=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!
M4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]
M"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H
M:79E.CI::7`["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*
M:68@*&1E9FEN960@)'!A<BD@>PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ
M92@Q,C@J,3`R-"D["F]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#
M86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*8FEN;6]D92@D9F@I.PIB;&5S<R@D
M9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@
M)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV
M93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@
M)"$B.PI]"FUY("5E;G8@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]
M("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI>
M<&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@
M("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FQO8V%L("0O(#T@7#0["FEF("AD
M969I;F5D("1P87(I('L*;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A
M.B`D<&%R(CL*8FEN;6]D92A005(I.PID:64@(B1P87(@:7,@;F]T(&$@4$%2
M(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["GT*0W)E871E
M4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/
M.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/
M.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE("0A.PIB:6YM;V1E
M*"1F:"D["B0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@
M.B!U;F1E9CL*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(@/2!S8V%L87(@
M/%]&2#X["FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^
M("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13
M=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A
M9&5R+"`D,"D*?0IF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2![
M"FUY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0["B1V86P@/2!E=F%L("1V
M86P@:68@)'9A;"`]?B`O7ELG(ETO.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%2
M7R(@+B!U8R@D:V5Y*2`N(")?7R(["FUY("1S970@/2`B4$%27R(@+B!U8R@D
M:V5Y*2`N("(])'9A;"(["B1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA
M9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T
M*2DI"GUE9SL*?0HD9F@M/G!R:6YT*"1L;V%D97(I.PHD+R`]('5N9&5F.PII
M9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ
M.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U
M;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D
M8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA
M<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E
M>'!]*3L*?2!`24Y#.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y
M;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@
M)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T["FUY("5W<FET
M=&5N.PIF;W)E86-H("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D;F%M92P@
M)&9I;&4I.PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1N86UE(#T@
M)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*)&9I;&4@/2`D7SL*;&%S
M=#L*?0IE;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<6B]I*2!["B@D
M9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD["FQA<W0["GT*96QS:68@*&TA7B]L
M;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA*2!["FEF("AM>2`D<F5F(#T@)%!!
M4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]
M("@D<F5F+"`D,2D["FQA<W0["GT*96QS:68@*"UF("(D9&ER+R0Q(BD@>PHH
M)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*
M;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N
M86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<
M421L:6)?97AT7$4D+SL*;W5T<R@@:F]I;B`B(BP*<7$H4&%C:VEN9R`B*2P@
M<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE+`IQ<2@B+BXN*0HI
M.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D
M9FEL92T^>V)U9GT["GT*96QS92!["F]P96X@1DE,12P@)SPG+"`D9FEL92!O
M<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*8FEN;6]D92A&24Q%*3L*
M)&-O;G1E;G0@/2`\1DE,13X["F-L;W-E($9)3$4["E!!4CHZ1FEL=&5R.CI0
M;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE*0II9B`A)$5.
M5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD
M+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C
M;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"F]U=',H<7$H5W)I='1E;B!A<R`B
M)&YA;64B*2D["B1F:"T^<')I;G0H(D9)3$4B*3L*)&9H+3YP<FEN="AP86-K
M*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L*)&9H+3YP<FEN="AS<')I;G1F
M*`HB)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT
M96YT*2P@)&YA;64**2D["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D
M8V]N=&5N="DI*3L*)&9H+3YP<FEN="@D8V]N=&5N="D["GT*?0HD>FEP+3YW
M<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["B1C86-H95]N86UE(#T@
M<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*:68@*"$D8V%C:&5?;F%M92!A
M;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["FUY("1C='@@/2!E
M=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q
M*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI3
M2$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG
M97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I
M9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E
M<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA
M9&1F:6QE*"1O=70L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T
M>"!A;F0@;W!E;BAM>2`D9F@L("(\)&]U="(I*2!["F)I;FUO9&4H)&9H*3L*
M)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PI]"GT*)&-A8VAE7VYA
M;64@/2`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE.PI]"B1C86-H
M95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD
M8V%C:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT*"1C86-H95]N86UE
M*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L
M;V%D97(I*2D["B1F:"T^<')I;G0H(EQN4$%2+G!M7&XB*3L*)&9H+3YC;&]S
M93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E
M9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!
M4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@
M1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)'II<"`]
M($%R8VAI=F4Z.EII<"T^;F5W.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.PHD
M9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"([
M"B1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@
M07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*<'5S:"!`
M4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE
M?2`]("1Z:7`["B1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["F]U=',H<7$H
M7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI.PII9B`H9&5F
M:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI
M<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I
M('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N
M86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?
M;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S
M:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=
M*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE
M(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A
M8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E
M<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7$H4VMI<'!I;F<@(B1M
M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T
M7VYA;64B*2D["GT@96QS92!["F]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E
M<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*)&UE;6)E<BT^97AT<F%C=%1O
M1FEL94YA;65D*"1D97-T7VYA;64I.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE
M*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB
M0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*
M57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@
M72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/
M;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G
M;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*
M;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H
M)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL
M97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*
M1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C
M(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S
M('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I
M;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q
M=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD[
M"G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U
M:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E
M;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q
M=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ
M1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E
M.CI::7`["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I
M<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*
M<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T
M=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER
M92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A
M;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R
M97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U
M:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@
M<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F
M:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N
M*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D
M<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!4
M14U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2![
M"FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M
M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U
M:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I
M;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R
M.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R
M;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T52
M3D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@
M/7X@<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L
M:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP
M9&ER+"`P-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE
M(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B`H;7D@)&9H+"`B/"(N
M("1P<F]G;F%M92D["G-E96L@)&9H+"`M,3@L(#(["G-Y<W)E860@)&9H+"!M
M>2`D8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L
M("TU."P@,CL*<WES<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O
M+V<["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U
M9CL*?0IE;'-E('L*;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ
M4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@
M1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R
M97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S
M:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\
M?"`P.PII9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I
M;VX@97$@)S4N,SDG*2!["B1C='@M/F%D9&9I;&4H)'!R;V=N86UE+"`B8B(I
M(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H
M+"`B/"1P<F]G;F%M92(I*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL
M92@D9F@I.PIC;&]S92@D9F@I.PI]"GT*)'-T;7!D:7(@+CT@(B1#;VYF:6=[
M7V1E;&EM?6-A8VAE+2(@+B`H("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D
M;71I;64@*3L*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!
M3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"([
M"GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L
M(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-
M4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W1E;7!F
M:6QE('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D
M9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L
M;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["F]P96X@
M;7D@)&9H+"`G/B<L("1T96UP;F%M92!O<B!D:64@(F-A;B=T('=R:71E("1T
M96UP;F%M93H@)"$B.PIB:6YM;V1E("1F:#L*<')I;G0@)&9H("1C;VYT96YT
M<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN
M960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL
M:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E
M=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A
M;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@
M/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@
M86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*
M)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M
M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/
M1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^
M/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T
M=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X
M97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*
M?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]
M7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%
M35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D
M0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@
M+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5]
M(CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\
M/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#
M;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ
M9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'
M971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D
M*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<
M12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]
M("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM0
M05)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD
M14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@
M5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12!!4D=#($%21U9?,"`I
M("D@>PID96QE=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)
M4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.
M5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!
M3%\G+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?
M("`@("`@("`@("`@("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T
M92`D14Y6>U!!4E]#3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?
M1TQ/0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A
M;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D
M,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U
M=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L
M;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I
M;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F
M:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP
M('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H
M97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!0
M05(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R
M="A`<&%R7V%R9W,I.PID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@
M<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y
M7&XI"G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ
M97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE
M("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ
M97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<
M*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?
M"@```````1L#.^P````<````V(#__S`!``"8A/__$`8``,B&__\(`0``^(;_
M_QP!``"XA___6`$``-B=__^H`0``J)[___0!```XG___(`(``)BA__]L`@``
M&*/__[@"``"HH___W`(``(BD__\@`P``R*3__S@#```8I?__5`,``-BE__^`
M`P``Z*7__Y0#``#XI___]`,``"BH__\(!```^*C__S@$``#HJO__7`0``&BK
M__]X!```F*O__Y@$``!XK/__V`0``)BW__^0!0``:+O__]P%``#(N___0`8`
M`#B\__^(!@``2+S__Z`&````````%``````````!>E(``7@0`1L,!PB0`0``
M$````!P```"XA?__+P````!$!Q`0````,````-2%__\%`````````"0```!$
M````H'___\`#````#A!&#AA*#PMW"(``/QH[*C,D(@````!,````;````%B&
M__\6%@```$(.$(\"2@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!T<.T`4#[14*
M#CA!#C!!#BA"#B!"#AA"#A!"#@A!"P```$@```"\````*)S__\P`````0@X0
MCP)"#AB.`T(.((T$0@XHC`5!#C"&!D$..(,'1`Y``FP*#CA$#C!!#BA"#B!"
M#AA"#A!"#@A)"P`H````"`$``*R<__^,`````$$.$(8"1`X8@P-$#C`">PH.
M&$$.$$$."$$+`$@````T`0``$)W__U,"````0@X0CP)"#AB.`T(.((T$0@XH
MC`5!#C"&!D0..(,'1PY@`Q\!"@XX00XP00XH0@X@0@X80@X00@X(0PM(````
M@`$``"2?__]\`0```$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!T<.
M\`%^"@XX00XP00XH0@X@0@X80@X00@X(1PL`(````,P!``!8H/__BP````!!
M#A"#`E(.L`$"<0H.$$$."$$+0````/`!``#$H/__WP````!"#A".`DH.&(T#
M0@X@C`1+#BB&!4$.,(,&1P[`(`*$"@XP00XH00X@0@X80@X00@X(0PL4````
M-`(``&"A__\S`````$0.$%D."``8````3`(``(BA__]"`````$$.$(,":`X(
M````*````&@"``"\H?__N@````!!#A"&`D$.&(,#1P[`0`*I"@X800X000X(
M00L0````E`(``%"B__\%`````````%P```"H`@``3*+__P("````0@X0CP)"
M#AB.`T(.((T$0@XHC`5$#C"&!DL..(,'1P[P(0)D"@XX00XP00XH0@X@0@X8
M0@X00@X(1`L"E@[X(4T.@")J#O@A00[P(0```!`````(`P``_*/__RD`````
M````+````!P#```8I/__S0````!3#A"#`@)-"L,."$@+`D`."$C#4`X0@P)(
MPPX(````(````$P#``"XI/__YP$```!!#A"#`DL.4`-L`0H.$$$."$<+&```
M`'`#``"$IO__=`````!$#B!O"@X(10L``!P```",`P``Z*;__R<`````1`X0
M6`H."$0+1@X(````/````*P#``#XIO__W@````!"#A",`D$.&(8#2PX@@P1$
M#C`"3`H.($$.&$$.$$(."$8+;@XX20Y`=`XX00XP`+0```#L`P``F*?__R`+
M````0@X0CP),#AB.`T(.((T$0@XHC`5!#C"&!D$..(,'1P[0@P(##@(.V(,"
M80[@@P)@#MB#`D(.T(,"`H`*#CA!#C!!#BA"#B!"#AA"#A!"#@A*"P."`0[8
M@P))#N"#`F`.V(,"00[0@P);#MB#`D4.X(,"3P[H@P)-#O"#`DL.T(,"`Z,$
M#MB#`D0.X(,":`[8@P)!#M"#`@,W`0H.V(,"0@[@@P),"P!(````I`0```"R
M___#`P```$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!T0.8`.R`@H.
M.$$.,$$.*$(.($(.&$(.$$(."$8+,````/`$``"$M?__7@````!!#A"&`D$.
M&(,#1PX@`D,*#AA!#A!!#@A""T0.&$0.$$$.""P````D!0``@'[__R$"````
M00X0A@)!#AB#`T0.4`.)`0H.&$$.$$$."$$+`````$0```!4!0``@+7__V4`
M````1@X0CP)%#AB.`T4.((T$10XHC`5(#C"&!D@..(,'1PY`;@XX00XP00XH
M0@X@0@X80@X00@X(`!0```"<!0``J+7__P4``````````````!````"T!0``
MH+7__Q``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````/`F0```````P"9````````!````````
M``$``````````0````````"^`0````````$`````````R0$````````!````
M`````-,!`````````0`````````B`@````````$`````````7P,````````/
M`````````-`$````````#```````````($````````T`````````H%M`````
M```9`````````&B]0```````&P`````````(`````````!H`````````<+U`
M```````<``````````@`````````]?[_;P````!``T````````4`````````
M,`U````````&`````````!@$0```````"@`````````+!0````````L`````
M````&``````````5`````````````````````P``````````P$````````(`
M````````B`4````````4``````````<`````````%P````````"(%$``````
M``<`````````@!-````````(``````````@!````````"0`````````8````
M`````/[__V\``````!-```````#___]O``````(`````````\/__;P`````\
M$D``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!XO4`````````````````````````````V($```````$8@
M0```````5B!```````!F($```````'8@0```````AB!```````"6($``````
M`*8@0```````MB!```````#&($```````-8@0```````YB!```````#V($``
M``````8A0```````%B%````````F(4```````#8A0```````1B%```````!6
M(4```````&8A0```````=B%```````"&(4```````)8A0```````IB%`````
M``"V(4```````,8A0```````UB%```````#F(4```````/8A0```````!B)`
M```````6(D```````"8B0```````-B)```````!&(D```````%8B0```````
M9B)```````!V(D```````(8B0```````EB)```````"F(D```````+8B0```
M````QB)```````#6(D```````.8B0```````]B)````````&(T```````!8C
M0```````)B-````````V(T```````$8C0```````5B-```````!F(T``````
M`'8C0```````AB-```````"6(T```````*8C0```````MB-```````#&(T``
M`````-8C0````````````````````````````/____\`````$&-```````!'
M0T,Z("A03$0M3&EN=7@I(#@N,BXP(#(P,3@P-S(V("AR96QE87-E*0``+G-H
M<W1R=&%B`"YI;G1E<G``+FYO=&4N04))+71A9P`N;F]T92YG;G4N8G5I;&0M
M:60`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N
M=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI=``N=&5X=``N
M9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE`"YI;FET7V%R
M<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC`"YG;W0`+F=O="YP;'0`+F1A=&$`
M+F)S<P`N8V]M;65N=```````````````````````````````````````````
M````````````````````````````````````````````````"P````$````"
M`````````.`"0```````X`(````````<`````````````````````0``````
M`````````````!,````'`````@````````#\`D```````/P"````````(```
M``````````````````0````````````````````A````!P````(`````````
M'`-````````<`P```````"0````````````````````$````````````````
M````-````/;__V\"`````````$`#0```````0`,```````#4``````````4`
M````````"````````````````````#X````+`````@`````````8!$``````
M`!@$````````&`D````````&`````0````@`````````&`````````!&````
M`P````(`````````,`U````````P#0````````L%```````````````````!
M````````````````````3@```/___V\"`````````#P20```````/!(`````
M``#"``````````4``````````@`````````"`````````%L```#^__]O`@``
M````````$T`````````3````````@``````````&`````@````@`````````
M``````````!J````!`````(`````````@!-```````"`$P````````@!````
M````!0`````````(`````````!@`````````=`````0```!"`````````(@4
M0```````B!0```````"(!0````````4````6````"``````````8````````
M`'X````!````!@``````````($`````````@````````&P``````````````
M``````0```````````````````!Y`````0````8`````````("!````````@
M(````````,`#```````````````````0`````````!``````````A`````$`
M```&`````````.`C0```````X",```````#`-P``````````````````$```
M`````````````````(H````!````!@````````"@6T```````*!;````````
M#0````````````````````0```````````````````"0`````0````(`````
M`````&!`````````8````````$@_```````````````````(````````````
M````````F`````$````"`````````$B?0```````2)\```````#L````````
M````````````!````````````````````*8````!`````@`````````XH$``
M`````#B@````````R`4```````````````````@```````````````````"P
M````#@````,`````````:+U```````!HK0````````@`````````````````
M```(``````````@`````````O`````\````#`````````'"]0```````<*T`
M```````(````````````````````"``````````(`````````,@````&````
M`P````````!XO4```````'BM````````,`(````````&``````````@`````
M````$`````````#1`````0````,`````````J+]```````"HKP```````%@`
M```````````````````(``````````@`````````U@````$````#````````
M``#`0````````+````````#P`0``````````````````"``````````(````
M`````-\````!`````P````````#PP4```````/"Q````````(```````````
M``````````@```````````````````#E````"`````,`````````(,)`````
M```0L@```````$@0```````````````````@````````````````````Z@``
M``$````P````````````````````$+(````````J````````````````````
M`0`````````!``````````$````#`````````````````````````#JR````
C````\P````````````````````$`````````````````````
